@@ -1,7 +1,7 @@
 package Complete::Path;
 
-our $DATE = '2015-09-17'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2015-09-22'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,7 +19,7 @@ sub _dig_leaf {
     my ($p, $list_func, $is_dir_func, $path_sep) = @_;
     my $num_dirs;
     my $listres = $list_func->($p, '', 0);
-    return $p unless @$listres == 1;
+    return $p unless ref($listres) eq 'ARRAY' && @$listres == 1;
     my $e = $listres->[0];
     my $p2 = $p =~ m!\Q$path_sep\E\z! ? "$p$e" : "$p$path_sep$e";
     my $is_dir;
@@ -40,7 +40,7 @@ $SPEC{complete_path} = {
     description => <<'_',
 
 Complete path, for anything path-like. Meant to be used as backend for other
-functions like `Complete::Util::complete_file` or
+functions like `Complete::File::complete_file` or
 `Complete::Module::complete_module`. Provides features like case-insensitive
 matching, expanding intermediate paths, and case mapping.
 
@@ -81,7 +81,7 @@ you already suffix names of "directories" with path separator in `list_func`.
 One reason you might want to provide this and not mark "directories" in
 `list_func` is when you want to do extra filtering with `filter_func`. Sometimes
 you do not want to suffix the names first (example: see `complete_file` in
-`Complete::Util`).
+`Complete::File`).
 
 _
         },
@@ -332,7 +332,7 @@ Complete::Path - Complete path
 
 =head1 VERSION
 
-This document describes version 0.18 of Complete::Path (from Perl distribution Complete-Path), released on 2015-09-17.
+This document describes version 0.19 of Complete::Path (from Perl distribution Complete-Path), released on 2015-09-22.
 
 =head1 DESCRIPTION
 
@@ -344,7 +344,7 @@ This document describes version 0.18 of Complete::Path (from Perl distribution C
 Complete path.
 
 Complete path, for anything path-like. Meant to be used as backend for other
-functions like C<Complete::Util::complete_file> or
+functions like C<Complete::File::complete_file> or
 C<Complete::Module::complete_module>. Provides features like case-insensitive
 matching, expanding intermediate paths, and case mapping.
 
@@ -395,7 +395,7 @@ you already suffix names of "directories" with path separator in C<list_func>.
 One reason you might want to provide this and not mark "directories" in
 C<list_func> is when you want to do extra filtering with C<filter_func>. Sometimes
 you do not want to suffix the names first (example: see C<complete_file> in
-C<Complete::Util>).
+C<Complete::File>).
 
 =item * B<list_func>* => I<code>
 
